import axios from 'axios'
import { Message, Loading } from 'element-ui'

// create an axios instance
const service = axios.create({
  baseURL: process.env.VUE_APP_API, // url = base url + request url
  // withCredentials: true, // send cookies when cross-domain requests
  timeout: 5000 // request timeout
})

let loading

// request interceptor
service.interceptors.request.use(
  config => {
    // 每个请求都默认要发送这些数据
    const data = {
      from: 0,
      page: 1, // 当前页数
      rows: 10, // 每页条数
      companyId: 0,
      sidx: '',
      sord: '',
      token: null,
      reqdata: {},
      userid: '123'
    }
    config.data = Object.assign(data, config.data)
    // 显示加载loading
    loading = Loading.service({
      lock: true,
      text: 'Loading',
      spinner: 'el-icon-loading',
      background: 'rgba(0, 0, 0, 0.7)'
    })
    return config
  },
  error => {
    // 如果出错了，打印出来
    console.log(error) // for debug
    return Promise.reject(error)
  }
)

// response interceptor
service.interceptors.response.use(
  response => {
    const res = response.data
    // 关闭loading
    loading.close()

    /*
    * 100 正常
    * 101 请求参数错误
    * */
    // 如果返回的数据状态码不是100，说明请求出错了
    if (res.state !== 100) {
      Message({
        message: res.msg || 'Error',
        type: 'error',
        duration: 5 * 1000
      })
      return Promise.reject(new Error(res.msg || 'Error'))
    } else {
      return res
    }
  },
  error => {
    console.log('err' + error) // for debug
    // 关闭loading
    loading.close()
    Message({
      message: error.message,
      type: 'error',
      duration: 5 * 1000
    })
    return Promise.reject(error)
  }
)

export default service
